==> style-o-matic-1.1.37.tgz: package/es/components/Drawer/Drawer.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import _ from "lodash";
import classNames from "classnames";
import { CoreComponent, getCorePropTypes, getCorePropDefaults, getValidProps, UIGlobals, ROLE } from "../../lib";
import "./Drawer.css";

var Drawer = (_temp = _class = function (_CoreComponent) {
  _inherits(Drawer, _CoreComponent);

  function Drawer(props) {
    _classCallCheck(this, Drawer);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _this.ensureAttachment = function () {
      if (_this.node) {
        var attachment = _this.state.attachment;

        var _this$node$getBoundin = _this.node.getBoundingClientRect(),
            width = _this$node$getBoundin.width,
            height = _this$node$getBoundin.height,
            top = _this$node$getBoundin.top,
            left = _this$node$getBoundin.left,
            bottom = _this$node$getBoundin.bottom,
            right = _this$node$getBoundin.right;

        var _UIGlobals$getScreenD = UIGlobals.getScreenDimensions(),
            screenHeight = _UIGlobals$getScreenD.height,
            screenWidth = _UIGlobals$getScreenD.width;

        var newAttach = attachment;
        if (height > screenHeight / 2) {
          newAttach = left > screenWidth / 2 ? "right" : "left";
        } else {
          newAttach = top > screenHeight / 2 ? "bottom" : "top";
        }
        if (newAttach !== attachment) {
          _this.setState({ attachment: newAttach });
        }
      }
    };

    _this.useParentNode = true;
    _this.state = {
      attachment: props.attach
    };
    return _this;
  }

  Drawer.prototype.componentDidMount = function componentDidMount() {
    this.ensureAttachment();
  };

  Drawer.prototype.render = function render() {
    var _classes,
        _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        active = _getValidProps.active,
        color = _getValidProps.color,
        colorStyle = _getValidProps.colorStyle,
        uuid = _getValidProps.uuid,
        attach = _getValidProps.attach,
        icon = _getValidProps.icon,
        disabled = _getValidProps.disabled,
        minimizable = _getValidProps.minimizable,
        children = _getValidProps.children,
        props = _getValidProps.props;

    this.ensureAttachment();
    var attachment = this.state.attachment;


    var classes = (_classes = {}, _classes["ui-drawer-" + attachment] = attachment, _classes.active = active, _classes.minimized = !active && minimizable, _classes);
    if (!_.isNil(color)) {
      var nohover = String(color).indexOf("!") !== -1;
      var cleanColor = String(color).replace("!", "");
      var colorClass = "ui-" + cleanColor;
      if (!_.isNil(colorStyle)) {
        colorClass += "-" + colorStyle;
      }
      if (nohover) {
        colorClass += "-no-hover";
      }
      classes[colorClass] = true;
    }

    return React.createElement(
      Component,
      _extends({}, props, {
        className: classNames("ui-drawer", classes),
        ref: this.onSetRef
      }),
      React.createElement(
        "div",
        { className: "ui-drawer-content" },
        React.Children.map(children, function (child) {
          return React.createElement(
            "div",
            { className: "ui-drawer-row" },
            _this2.renderChild(child, {
              disabled: disabled,
              uiclass: uiclass,
              active: active
            })
          );
        })
      )
    );
  };

  return Drawer;
}(CoreComponent), _class.propTypes = getCorePropTypes({
  minimizable: "bool",
  defaultOpen: "bool",
  icon: "string"
}), _class.defaultProps = getCorePropDefaults({
  uirole: ROLE.DRAWER,
  minimizable: true,
  defaultOpen: false,
  icon: "fa fa-bars",
  attach: "left"
}), _temp);


export default Drawer;

==> style-o-matic-1.2.0.tgz: package/es/components/Drawer/Drawer.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @memberof components
 * @namespace Drawer
 * @author Steven Jackson
* @scss ../../scss/components/Drawer
 * @example <Drawer>
             Example Content
           </Drawer>
 */
import React from "react";
import _ from "lodash";
import classNames from "classnames";
import { CoreComponent, setCorePropDefaults, getValidProps, UIGlobals, ROLE } from "../../lib";
import Content from "../Content/Content.js";
import "./Drawer.css";

var Drawer = (_temp = _class = function (_CoreComponent) {
  _inherits(Drawer, _CoreComponent);

  function Drawer() {
    _classCallCheck(this, Drawer);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  Drawer.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        color = _getValidProps.color,
        colorStyle = _getValidProps.colorStyle,
        uuid = _getValidProps.uuid,
        fixed = _getValidProps.fixed,
        disabled = _getValidProps.disabled,
        collapsed = _getValidProps.collapsed,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      props,
      React.createElement(
        Content,
        null,
        React.Children.map(children, function (child) {
          return _this2.renderChild(child, {
            disabled: disabled,
            uiclass: uiclass,
            collapsed: collapsed
          });
        })
      )
    );
  };

  return Drawer;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  uirole: ROLE.DRAWER,
  collapsed: true
}), _temp);


export default Drawer;
